#
# spec file for package bridge-utils
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bridge-utils
Version:        1.7.1
Release:        2.5
Summary:        Utilities for Configuring the Linux Ethernet Bridge
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Routing
URL:            https://www.linuxfoundation.org/collaborate/workgroups/networking/bridge
Source0:        https://mirrors.edge.kernel.org/pub/linux/utils/net/bridge-utils/%{name}-%{version}.tar.xz
Source1:        https://mirrors.edge.kernel.org/pub/linux/utils/net/bridge-utils/%{name}-%{version}.tar.sign
Patch0:         %{name}-1.5-hz.diff
Patch1:         %{name}-1.5-optflags.patch
Patch2:         bridge-utils-1.5-ip6.patch
BuildRequires:  automake
BuildRequires:  libsysfs

%description
This package contains utilities for configuring the Linux ethernet
bridge. The Linux ethernet bridge can be used for connecting multiple
ethernet devices together. The connection is fully transparent: hosts
connected to one ethernet device see hosts connected to the other
ethernet devices directly.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description devel
The %{name} devel package contains files needed for development.

%prep
%autosetup -p0

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
autoreconf -fiv
%configure
%make_build

%install
%make_install
install -d -m 755 %{buildroot}/sbin
install -D -m 644 libbridge/libbridge.h %{buildroot}%{_includedir}/libbridge.h
install -D -m 644 libbridge/libbridge.a %{buildroot}%{_libdir}/libbridge.a

%files
%defattr(-,root,root)
%license COPYING
%doc AUTHORS ChangeLog README THANKS doc/[FHPRSW]*
%{_mandir}/man?/*
%{_sbindir}/*

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/lib*

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Thu Jun  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.7.1
  * fix string overflow warnings
  * brctl: fix spelling on man page
* Tue Oct 27 2020 Pedro Monreal <pmonreal@suse.com>
- This utility is DEPRECATED. No new features will ever be added.
  Instead use the bridge command from the iproute2 package which
  supports more features.
- Update to version 1.7
  * Replace references to enslave
  * Remove out of date TODO
  * brctl: fix signed/unsigned comparison warnings
  * libbridge: add missing sys/time.h include in header
  * libbridge: Include the configured CFLAGS when compiling
- Update project URLs
- Rebase patches:
  * bridge-utils-1.5-ip6.patch
  * bridge-utils-1.5-optflags.patch
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
* Tue Oct 18 2016 tchvatal@suse.com
- Version update to 1.6:
  * Various tiny fixes, nothing ground breaking
- Refresh patch bridge-utils-1.5-ip6.patch (fuzz)
* Thu Dec  3 2015 tchvatal@suse.com
- Cleanup with spec-cleaner
- Remove the /sbin/ link, it should not be needed.
  Lets see what breaks, people should migrate to bridge anwyay
* Mon May 27 2013 mhrusecky@suse.cz
- added missing include to fix build in factory
  bridge-utils-1.5-ip6.patch
* Thu Mar 21 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Thu Feb  2 2012 rschweikert@suse.com
- Create -devel package to fix rpmlint errors
- Keep the binary in /usr/sbin, create link to /sbin (UsrMerge project)
  This does not effect resolution of #707837 as /sbin/brctl can still be
  found. systemd properly supports separate /usr
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Tue Aug 30 2011 andrea.turrini@gmail.com
- removed duplicated "Authors:" from description of bridge-utils.spec
* Mon Jul 25 2011 lidongyang@novell.com
- bnc#707837 - network:utilities/bridge-utils: Bug in Factory 12.1
  brctl has changed from /sbin to /usr/sbin
  revert the changes made to %%install section of the spec file
* Wed Jun  8 2011 lidongyang@novell.com
- update to 1.5
* Sun Dec 20 2009 jengelh@medozas.de
- enable parallel build
* Tue May  6 2008 crrodriguez@suse.de
- fix for Feature No 300498 , use RPM_OPT_FLAGS everywhere.
* Wed Jan  9 2008 prusnak@suse.cz
- update to 1.4
* Tue Oct 17 2006 mjancar@suse.cz
- update to 1.2
  * Fixed bug where setting port priority set path cost instead
* Mon Aug  7 2006 ro@suse.de
- define HZ to sysconf(_SC_CLK_TCK) if not defined
* Thu Jul 27 2006 mjancar@suse.cz
- update to 1.1
  * Change to use libsysfs 2.0
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct  5 2005 dmueller@suse.de
- add norootforbuild
* Mon Aug  1 2005 mjancar@suse.cz
- update to 1.0.6
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Fri Aug 13 2004 mjancar@suse.cz
- update to 1.0.4
* Fri Jun 20 2003 mjancar@suse.cz
- initial version 0.9.6
